@@ -187,7 +187,7 @@ def read_bam(f, sparse=True, as_df=False, mapq=0, required_flag=0, filter_flag=1
         sys.exit(1)
 
     if bamread.__version__ in ["0.0.1", "0.0.2", "0.0.3", "0.0.4",
-0                               "0.0.5", "0.0.6", "0.0.7", "0.0.8", "0.0.9"]:
+                               "0.0.5", "0.0.6", "0.0.7", "0.0.8", "0.0.9"]:
         print("bamread not recent enough. Must be 0.0.10 or higher. Use `conda install -c bioconda 'bamread>=0.0.10'` or `pip install bamread>=0.0.10` to install it.")
         sys.exit(1)
 
@@ -365,8 +365,7 @@ def to_rows(anno):
 
     for l in anno:
         rowdicts.append({k: v
-                         for k, v in [kv.replace('"', '').split(None, 1)
-                                      # l[:-1] removes final ";" cheaply
+                         for k, v in [kv.replace('""', '"NA"').replace('"', '').split(None, 1)
                                       for kv in l[:-1].split("; ")]})
 
     return pd.DataFrame.from_dict(rowdicts).set_index(anno.index)
@@ -428,9 +427,6 @@ def read_gtf_restricted(f,
 
     dfs = []
     for df in df_iter:
-        # Since Start is 1-indexed
-        df.Start -= 1
-
         if sum(df.Score == ".") == len(df):
             cols_to_concat = "Chromosome Start End Strand Feature".split()
         else:
